# streamlit-custom-component

Streamlit component that allows you to do X

## Installation instructions

```sh
pip install cookyjar
```

## Usage instructions

```python
import streamlit as st

from cookyjar import cookyjar

cookies = cookyjar()

st.write(value)
```